# flake8: noqa
from skale.contracts.base_contract import BaseContract, transaction_method
from skale.contracts.config_controller.config_controller import ConfigController

__all__ = ['ConfigController']
